set echo off;
set verbose off;
use DB;
load davddk.sql;
use DB;
load dav_acct.sql;
use DB;
load dav.sql;
use DB;
load dav_api.sql;
use DB;
load uriqa.sql;
use DB;
load snapshot_repl.sql;
use DB;
load DET_HostFs.sql;
use DB;
load DET_PropFilter.sql;
use DB;
load DET_ResFilter.sql;
use DB;
load DET_CatFilter.sql;
use DB;
load DET_S3.sql;
use DB;
load Versioning/DET_Versioning.sql;
